# Testcase run by default. To disable: rpm(or rpmbuild) -ba --define 'dotests 0' gzip*.spec
%{!?dotests: %define dotests 1}

%global VERSION  7.1.0
%global Patchlevel 13 


Name:           ImageMagick
Version:        %{VERSION}.%{Patchlevel}
Release:        1
Summary:        Viewer and Converter for Images
Group:          Applications/Multimedia
License:        https://imagemagick.org/script/license.php
Url:            https://imagemagick.org/
Source0:        https://imagemagick.org/download/%{name}/%{name}-%{VERSION}-%{Patchlevel}.tar.gz
Patch0:         ImageMagick-aix-dlname.patch
Patch1: 	ImageMagick-libxml2.patch

BuildRequires:  bzip2-devel >= 1.0.8, freetype2-devel >= 2.10.4 , libjpeg-devel >= 9c, libpng-devel >= 1.6.27
BuildRequires:  libtiff-devel >= 4.1.0 , zlib-devel >= 1.2.11
BuildRequires:  ghostscript-devel >= 9.53.3 
BuildRequires:  libxml2-devel >= 2.9.10
BuildRequires:  libwebp-devel >= 1.0.2 
BuildRequires:  jbigkit-devel >= 2.1
BuildRequires:  cairo-devel >= 1.14.6
BuildRequires:  autoconf >= 2.69, automake >= 1.16.1, libtool-ltdl-devel >= 2.4.6
BuildRequires:  coreutils >= 8.29

Requires:       %{name}-libs = %{version}-%{release}
Requires:       libgomp >= 8.3.0
Requires:       freetype2 >= 2.10.4 
Requires:       libxml2 >= 2.9.10
Requires:       bzip2   >= 1.0.8

%description
ImageMagick® is a software suite to create, edit, compose, or convert bitmap images. It can read and write images in a variety of formats (over 200) including PNG, JPEG, JPEG-2000, GIF, TIFF, DPX, EXR, WebP, Postscript, PDF, and SVG. Use ImageMagick to resize, flip, mirror, rotate, distort, shear and transform images, adjust image colors, apply various special effects, or draw text, lines, polygons, ellipses and Bézier curves.

The functionality of ImageMagick is typically utilized from the command-line or you can use the features from programs written in your favorite language. Choose from these interfaces: G2F (Ada), MagickCore (C), MagickWand (C), ChMagick (Ch), ImageMagickObject (COM+), Magick++ (C++), JMagick (Java), L-Magick (Lisp), Lua (LuaJIT), NMagick (Neko/haXe), Magick.NET (.NET), PascalMagick (Pascal), PerlMagick (Perl), MagickWand for PHP (PHP), IMagick (PHP), PythonMagick (Python), RMagick (Ruby), or TclMagick (Tcl/TK). With a language interface, use ImageMagick to modify or create images dynamically and automagically.

ImageMagick utilizes multiple computational threads to increase performance and can read, process, or write mega-, giga-, or tera-pixel image sizes.

ImageMagick is free software delivered as a ready-to-run binary distribution or as source code that you may use, copy, modify, and distribute in both open and proprietary applications. It is distributed under the Apache 2.0 license.

The ImageMagick development process ensures a stable API and ABI. Before each ImageMagick release, we perform a comprehensive security assessment that includes memory error and thread data race detection to prevent security vulnerabilities.

The authoritative ImageMagick web site is https://imagemagick.org. The authoritative source code repository is http://git.imagemagick.org/repos/ImageMagick. We maintain a source code mirror at GitHub.

%package devel
Summary: Library links and header files for ImageMagick application development
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: ghostscript-devel >= 9.53.3
Requires: bzip2-devel >= 1.0.8, freetype2-devel >= 2.10.4, libtiff-devel >= 4.1.0, libjpeg-devel >= 9c
Requires: libwebp-devel >= 1.0.2, cairo-devel >= 1.14.6, pkg-config >= 0.29.2 
Requires: %{name}-libs = %{version}-%{release}

%description devel
ImageMagick-devel contains the library links and header files you'll
need to develop ImageMagick applications. ImageMagick is an image
manipulation program.

If you want to create applications that will use ImageMagick code or
APIs, you need to install ImageMagick-devel as well as ImageMagick.
You do not need to install it if you just want to use ImageMagick,
however.

%package libs
Summary: ImageMagick libraries to link with
Group: Applications/Multimedia

Requires: libgcc >= 8.3.0
Requires: libgomp >= 8.3.0
Requires: xz-libs >= 5.2.4
Requires: libxml2 >= 2.9.10
Requires: libtiff >= 4.1.0 
Requires: fontconfig >= 2.11.95
Requires: libpng >= 1.6.27
Requires: glib2 >= 2.56.1-2
Requires: bzip2 >= 1.0.8
Requires: libjpeg >= 9c
Requires: freetype2 >= 2.10.4
Requires: zlib >= 1.2.11
Requires: libwebp >= 1.0.2
Requires: cairo >= 1.14.6


%description libs
This packages contains a shared libraries to use within other applications.


%package doc
Summary: ImageMagick HTML documentation
Group: Documentation

%description doc
ImageMagick documentation, this package contains usage (for the
commandline tools) and API (for the libraries) documentation in HTML format.
Note this documentation can also be found on the ImageMagick website:
https://imagemagick.org/.


%package c++
Summary: ImageMagick Magick++ library (C++ bindings)
Group: System Environment/Libraries

Requires: %{name}-libs = %{version}-%{release}
Requires: libgcc >= 8.3.0
Requires: libgomp >= 8.3.0
Requires: libstdc++ >= 8.3.0
Requires: freetype2 >= 2.10.4 
Requires: libxml2 >= 2.9.10
Requires: bzip2 >= 1.0.8

%description c++
This package contains the Magick++ library, a C++ binding to the ImageMagick
graphics manipulation library.

Install ImageMagick-c++ if you want to use any applications that use Magick++.


%package c++-devel
Summary: C++ bindings for the ImageMagick library
Group: Development/Libraries
Requires: %{name}-c++ = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}

%description c++-devel
ImageMagick-devel contains the static libraries and header files you'll
need to develop ImageMagick applications using the Magick++ C++ bindings.
ImageMagick is an image manipulation program.

If you want to create applications that will use Magick++ code
or APIs, you'll need to install ImageMagick-c++-devel, ImageMagick-devel and
ImageMagick.

You don't need to install it if you just want to use ImageMagick, or if you
want to develop/compile applications using the ImageMagick C interface,
however.


%prep
%setup -q -n %{name}-%{VERSION}-%{Patchlevel}
%patch0 -p1
%patch1

# for %%doc
mkdir Magick++/examples
cp -p Magick++/demo/*.cpp Magick++/demo/*.miff Magick++/examples

%build

export CC="gcc -maix64"
export CXX="g++ -maix64"
export CFLAGS="-O2 -I/opt/freeware/include -I/usr/include -D_LINUX_SOURCE_COMPAT"
export CXXFLAGS="-O2 -I/opt/freeware/include -I/usr/include -D_LINUX_SOURCE_COMPAT"
# ImageMagick internally adds "-pthread" compile flag so add the gcc pthread specific libpath in blibpath 
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib -Wl,-blibpath:/opt/freeware/lib/pthread/ppc64:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib"
export OBJECT_MODE=64

./configure --prefix=%{_prefix} \
        --libdir=%{_libdir}64 \
        --mandir=%{_mandir} \
        --enable-shared \
        --disable-static \
        --with-modules \
        --with-x \
        --with-threads \
        --with-xml \
        --without-gcc-arch \
        --with-jbig   \
	--with-magick_plus_plus

# Do *NOT* use %%{?_smp_mflags}, this causes PerlMagick to be silently misbuild
gmake V=1

if [ "%{dotests}" == 1 ]
then
    ( gmake -k check || true )
    /usr/sbin/slibclean
fi

%install
export OBJECT_MODE=64
make install DESTDIR=%{buildroot} INSTALL="install -p"
cp -a www/source %{buildroot}%{_datadir}/doc/%{name}-%{VERSION}
rm %{buildroot}%{_libdir}64/*.la
/usr/bin/strip %{buildroot}%{_bindir}/magick

%files
%defattr(-,root,system)
%doc README.txt LICENSE NOTICE AUTHORS.txt NEWS.txt ChangeLog 
%{_bindir}/[a-z]*
%{_mandir}/man[145]/[a-z]*
%{_mandir}/man1/%{name}.*

%files libs
%defattr(-,root,system)
%doc LICENSE NOTICE AUTHORS.txt QuickStart.txt
%{_libdir}64/libMagickCore-7.Q16HDRI.a
%{_libdir}64/libMagickWand-7.Q16HDRI.a
%{_libdir}64/%{name}-%{VERSION}
%{_datadir}/%{name}-7
%dir %{_sysconfdir}/%{name}-7
%config(noreplace) %{_sysconfdir}/%{name}-7/*.xml

%files devel
%defattr(-,root,system)
%{_bindir}/MagickCore-config
%{_bindir}/MagickWand-config
%{_libdir}64/pkgconfig/MagickCore.pc
%{_libdir}64/pkgconfig/MagickCore-7.Q16HDRI.pc
%{_libdir}64/pkgconfig/ImageMagick.pc
%{_libdir}64/pkgconfig/ImageMagick-7.Q16HDRI.pc
%{_libdir}64/pkgconfig/MagickWand.pc
%{_libdir}64/pkgconfig/MagickWand-7.Q16HDRI.pc
%dir %{_includedir}/%{name}-7
%{_includedir}/%{name}-7/MagickCore
%{_includedir}/%{name}-7/MagickWand
%{_mandir}/man1/MagickCore-config.*
%{_mandir}/man1/MagickWand-config.*

%files doc
%defattr(-,root,system)
%doc %{_datadir}/doc/%{name}-7
%doc %{_datadir}/doc/%{name}-%{VERSION}
%doc LICENSE

%files -n ImageMagick-c++
%defattr(-,root,system)
%doc Magick++/AUTHORS Magick++/ChangeLog Magick++/NEWS Magick++/README
%doc www/Magick++/COPYING
%{_libdir}64/libMagick++-7.Q16HDRI.a

%files c++-devel
%defattr(-,root,system)
%doc Magick++/examples
%{_bindir}/Magick++-config
%{_includedir}/%{name}-7/Magick++
%{_includedir}/%{name}-7/Magick++.h
%{_libdir}64/pkgconfig/Magick++.pc
%{_libdir}64/pkgconfig/Magick++-7.Q16HDRI.pc
%{_mandir}/man1/Magick++-config.*

%changelog
* Mon Nov 22 2021 Rishita Saha <risaha16@in.ibm.com> - 7.1.0-13
- Update to fix CVE-2021-39212

* Tue Apr 27 2021 Rishita Saha <risaha16@in.ibm.com> - 7.0.11.7-1
- Updated to version 7.0.11.0-1 to fix CVE-2020-27829

* Wed Jul 29 2020 Baanu Tumma <btumma15@in.ibm.com> - 7.0.10.23-1
- Updated to version 7.0.10.23-1 to fix CVE-2020-13902

* Mon Dec 16 2019 Ayappan P <ayappap2@in.ibm.com> - 7.0.9.8-1
- Update to version 7.0.9-8

* Tue Sep 24 2019 Ayappan P <ayappap2@in.ibm.com> - 7.0.8.61-2
- Add proper dependency on freetype2-devel
- Enable libwebp support

* Tue Aug 20 2019 Ayappan P <ayappap2@in.ibm.com> - 7.0.8.61-1
- Port to AIX Toolbox
